@@ -46,9 +46,7 @@
  * #ClutterInterval is available since Clutter 1.0
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <stdlib.h>
 #include <string.h>
@@ -61,7 +59,10 @@
 #include "clutter-interval.h"
 #include "clutter-private.h"
 #include "clutter-units.h"
+#include "clutter-scriptable.h"
+#include "clutter-script-private.h"
 
+#define CLUTTER_DISABLE_DEPRECATION_WARNINGS
 #include "deprecated/clutter-fixed.h"
 
 enum
@@ -93,7 +94,15 @@ struct _ClutterIntervalPrivate
   GValue *values;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (ClutterInterval, clutter_interval, G_TYPE_INITIALLY_UNOWNED)
+static void clutter_scriptable_iface_init (ClutterScriptableIface *iface);
+
+G_DEFINE_TYPE_WITH_CODE (ClutterInterval,
+                         clutter_interval,
+                         G_TYPE_INITIALLY_UNOWNED,
+                         G_ADD_PRIVATE (ClutterInterval)
+                         G_IMPLEMENT_INTERFACE (CLUTTER_TYPE_SCRIPTABLE,
+                                                clutter_scriptable_iface_init));
+
 
 static gboolean
 clutter_interval_real_validate (ClutterInterval *interval,
@@ -101,6 +110,8 @@ clutter_interval_real_validate (ClutterInterval *interval,
 {
   GType pspec_gtype = G_PARAM_SPEC_VALUE_TYPE (pspec);
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
+
   /* check the GTypes we provide first */
   if (pspec_gtype == COGL_TYPE_FIXED)
     {
@@ -116,6 +127,8 @@ clutter_interval_real_validate (ClutterInterval *interval,
         return FALSE;
     }
 
+G_GNUC_END_IGNORE_DEPRECATIONS;
+
   /* then check the fundamental types */
   switch (G_TYPE_FUNDAMENTAL (pspec_gtype))
     {
@@ -479,6 +492,47 @@ clutter_interval_get_property (GObject    *gobject,
     }
 }
 
+static gboolean
+clutter_interval_parse_custom_node (ClutterScriptable *scriptable,
+                                    ClutterScript     *script,
+                                    GValue            *value,
+                                    const gchar       *name,
+                                    JsonNode          *node)
+{
+  ClutterIntervalPrivate *priv = CLUTTER_INTERVAL (scriptable)->priv;
+
+  if ((strcmp (name, "initial") == 0) || (strcmp (name, "final") == 0))
+    {
+      g_value_init (value, priv->value_type);
+      return _clutter_script_parse_node (script, value, name, node, NULL);
+    }
+
+  return FALSE;
+}
+
+static void
+clutter_interval_set_custom_property (ClutterScriptable *scriptable,
+                                      ClutterScript     *script,
+                                      const gchar       *name,
+                                      const GValue      *value)
+{
+  ClutterInterval *self = CLUTTER_INTERVAL (scriptable);
+
+  if (strcmp (name, "initial") == 0)
+    clutter_interval_set_initial_value (self, value);
+  else if (strcmp (name, "final") == 0)
+    clutter_interval_set_final_value (self, value);
+  else
+    g_object_set_property (G_OBJECT (scriptable), name, value);
+}
+
+static void
+clutter_scriptable_iface_init (ClutterScriptableIface *iface)
+{
+  iface->parse_custom_node = clutter_interval_parse_custom_node;
+  iface->set_custom_property = clutter_interval_set_custom_property;
+}
+
 static void
 clutter_interval_class_init (ClutterIntervalClass *klass)
 {
